@@ -593,7 +593,7 @@ GVApi::parseHiddenLoginFields(const QString &strResponse, QVariantMap &ret)
             goto gonext;
         }
 
-        if (!xmlHandler.elems.contains ("input") || 
+        if (!xmlHandler.elems.contains ("input") ||
             !xmlHandler.attrMap.contains("input")) {
             Q_WARN("Failed to parse input field.");
             goto gonext;
@@ -738,7 +738,7 @@ GVApi::parseAlternateLogins(const QString &form, AsyncTaskToken *task)
             goto gonext;
         }
 
-        if (!xmlHandler.elems.contains ("input") || 
+        if (!xmlHandler.elems.contains ("input") ||
             !xmlHandler.attrMap.contains("input")) {
                 Q_WARN("Failed to parse input field.");
                 goto gonext;
@@ -1551,7 +1551,7 @@ GVApi::parseInboxJson(AsyncTaskToken *token, const QString &strJson,
 {
     bool rv = false;
 
-    QString strFixedHtml = strHtml;
+    QString strFixedHtml = "<html>" + strHtml + "</html>";
     strFixedHtml.replace ("&", "&amp;");
 
     QTemporaryFile fHtml, fSms;
@@ -1566,6 +1566,20 @@ GVApi::parseInboxJson(AsyncTaskToken *token, const QString &strJson,
     fHtml.write(strFixedHtml.toUtf8());
     fHtml.seek(0);
 
+#if 0
+    QFile fTemp1("inbox-html.html");
+    fTemp1.open (QFile::ReadWrite);
+    fTemp1.write (strFixedHtml.toUtf8());
+    fTemp1.close ();
+#endif
+
+#if 0
+    QFile fTemp2("inbox-json.json");
+    fTemp2.open (QFile::ReadWrite);
+    fTemp2.write (strJson.toUtf8());
+    fTemp2.close ();
+#endif
+
     do {
         QString strTemp;
         strTemp = "var obj = " + strJson;
@@ -1726,7 +1740,8 @@ GVApi::parseInboxJson(AsyncTaskToken *token, const QString &strJson,
 
                 QString strSmsRow;
                 if (!resultSms.isEmpty ()) {
-                    result = "<div><div class=\"gc-message-sms-row\">" + resultSms
+                    result = "<div><div class=\"gc-message-sms-row\">"
+                           + resultSms
                            + "</div></div>";
                 }
 
