@@ -22,13 +22,14 @@ Contact: yuvraaj@gmail.com
 #include "MainWindow.h"
 #include "AbstractItemModel.hpp"
 #include "ContactsModel.h"
+#include "ContactNumbersModel.h"
 #include "InboxModel.h"
 #include "GVNumModel.h"
 
 using namespace bb::cascades;
 
 QCoreApplication *
-createApplication(int argc, char **argv)
+createAppObject(int argc, char **argv)
 {
 	Application *app = new Application(argc, argv);
 
@@ -41,7 +42,7 @@ createApplication(int argc, char **argv)
     }
 
 	return app;
-}
+}//createAppObject
 
 MainWindow::MainWindow(QCoreApplication *_app)
 : IMainWindow(_app)
@@ -285,6 +286,12 @@ MainWindow::uiRefreshInbox()
     qml->setContextProperty("g_inboxModel", oInbox.m_inboxModel);
 }//MainWindow::uiRefreshInbox
 
+void
+MainWindow::uiSetSelelctedInbox(const QString &selection)
+{
+    Q_DEBUG(selection);
+}//MainWindow::uiSetSelelctedInbox
+
 void
 MainWindow::uiSetNewRegNumbersModel()
 {
@@ -361,6 +368,8 @@ void
 MainWindow::uiSetNewContactDetailsModel()
 {
     Q_DEBUG("Got new contact details model");
+    qml->setContextProperty("g_ContactPhonesModel",
+                            oContacts.m_contactPhonesModel);
 }//MainWindow::uiSetNewContactDetailsModel
 
 void
@@ -388,3 +397,23 @@ MainWindow::uiGetCIDetails(GVRegisteredNumber & /*num*/,
     Q_WARN("Should NEVER be here");
     Q_ASSERT(0 == "Should never get here");
 }//MainWindow::uiGetCIDetails
+
+void
+MainWindow::uiLongTaskBegins()
+{
+    //Q_ASSERT(0 == "Not implemented");
+    Q_DEBUG(m_taskInfo.suggestedStatus);
+}//MainWindow::uiLongTaskBegins
+
+void
+MainWindow::uiLongTaskContinues()
+{
+    //Q_ASSERT(0 == "Not implemented");
+    Q_DEBUG(m_taskInfo.suggestedStatus);
+}//MainWindow::uiLongTaskContinues
+
+void
+MainWindow::uiLongTaskEnds()
+{
+    Q_DEBUG("Status cleared");
+}//MainWindow::uiLongTaskEnds
