@@ -52,7 +52,7 @@ class ContactsModel;
 /*!
  * @brief Application pane object
  *
- *Use this object to create and init app UI, to create context objects, to register the new meta types etc.
+ * Use this object to create and init app UI, to create context objects, to register the new meta types etc.
  */
 class MainWindow : public IMainWindow
 {
@@ -76,6 +76,8 @@ public:
     void uiRefreshContacts();
     void uiRefreshInbox();
 
+    void uiSetSelelctedInbox(const QString &selection);
+
     void uiSetNewRegNumbersModel();
     void uiRefreshNumbers();
 
@@ -86,6 +88,10 @@ public:
 
     void uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model);
 
+    void uiLongTaskBegins();
+    void uiLongTaskContinues();
+    void uiLongTaskEnds();
+
 protected:
     QObject *getQMLObject(const char *objectName);
 
@@ -124,6 +130,6 @@ private:
 };
 
 QCoreApplication *
-createApplication(int argc, char **argv);
+createAppObject(int argc, char **argv);
 
 #endif /* MainWindow_HPP_ */
