@@ -139,18 +139,6 @@ CacheDb::ensureCache ()
                         GV_L_DATA   " varchar)");
     }
 
-    // Ensure that the registered numbers table is present. If not, create it.
-    if (!arrTables.contains (GV_REG_NUMS_TABLE)) {
-        query.exec ("CREATE TABLE " GV_REG_NUMS_TABLE " "
-                    "(" GV_RN_NAME           " varchar, "
-                        GV_RN_NUM            " varchar, "
-                        GV_RN_TYPE           " tinyint, "
-                        GV_RN_FLAGS          " integer, "
-                        GV_RN_FWDCOUNTRY     " varchar, "
-                        GV_RN_DISPUNVERIFYDT " varchar"
-                    ")");
-    }
-
     // Ensure that the call initiators table is present. If not, create it.
     if (!arrTables.contains (GV_CI_TABLE)) {
         query.exec ("CREATE TABLE " GV_CI_TABLE " "
@@ -823,7 +811,7 @@ CacheDb::clearInbox ()
 
 void
 CacheDb::refreshInboxModel (InboxModel *modelInbox,
-                                  const QString &strType)
+                            const QString &strType)
 {
     //  0,    1,    2,      3,    4,     5
     // id, type, name, number, time, flags
@@ -834,7 +822,7 @@ CacheDb::refreshInboxModel (InboxModel *modelInbox,
                          "," GV_IN_PHONE
                          "," GV_IN_ATTIME
                          "," GV_IN_FLAGS
-                   " FROM "   GV_INBOX_TABLE;
+                   " FROM "  GV_INBOX_TABLE;
     if (GVIE_Unknown != Type) {
         strQ += QString (" WHERE " GV_IN_TYPE "=%1 ").arg (Type);
     }
@@ -874,20 +862,10 @@ CacheDb::getInboxCount (GVI_Entry_Type Type) const
 bool
 CacheDb::existsInboxEntry (const GVInboxEntry &hEvent)
 {
-    CacheDbPrivate &p = CacheDbPrivate::ref ();
-    QSqlQuery query(p.db);
-    query.setForwardOnly (true);
+    GVInboxEntry e;
+    e.id = hEvent.id;
 
-    QString scrubId = hEvent.id;
-    scrubId.replace ("'", "''");
-    query.exec (QString ("SELECT " GV_IN_ID " FROM " GV_INBOX_TABLE " "
-                         "WHERE " GV_IN_ID "='%1'")
-                .arg (scrubId));
-    if (query.next ()) {
-        return true;
-    }
-
-    return false;
+    return getInboxEntryById (e);
 }//CacheDb::existsInboxEntry
 
 bool
@@ -1028,9 +1006,13 @@ CacheDb::getInboxEntryById (GVInboxEntry &hEvent)
     quint32 flags;
     QString scrubId = hEvent.id;
     scrubId.replace ("'", "''");
-    query.exec (QString ("SELECT " GV_IN_TYPE","GV_IN_ATTIME","GV_IN_DISPNUM","
-                                   GV_IN_PHONE","GV_IN_FLAGS","GV_IN_SMSTEXT","
-                                   GV_IN_NOTE" "
+    query.exec (QString ("SELECT " GV_IN_TYPE
+                               "," GV_IN_ATTIME
+                               "," GV_IN_DISPNUM
+                               "," GV_IN_PHONE
+                               "," GV_IN_FLAGS
+                               "," GV_IN_SMSTEXT
+                               "," GV_IN_NOTE " "
                          "FROM " GV_INBOX_TABLE " "
                          "WHERE " GV_IN_ID "='%1'")
                 .arg (scrubId));
@@ -1243,3 +1225,184 @@ CacheDb::putSelectedPhone (const QString &id)
     p.settings->setValue (GV_S_VAR_SELECTED_PHONE, id);
     return (true);
 }//CacheDb::putSelectedPhone
+
+QStringList
+CacheDb::getTextsByContact(const QString &strContact)
+{
+    CacheDbPrivate &p = CacheDbPrivate::ref();
+    QStringList arrNums;
+    QStringList rv;
+
+    // Search for the contact as if it were a number
+    ContactInfo info;
+    if (getContactFromNumber (strContact, info)) {
+        foreach (PhoneInfo phone, info.arrPhones) {
+            GVApi::simplify_number (phone.strNumber, false);
+            arrNums += phone.strNumber.replace("'", "''");
+        }
+    }
+
+    // Search for the contact as if it were a name
+    QSqlQuery query(p.db);
+    query.setForwardOnly (true);
+
+    QString scrubContact = strContact;
+    scrubContact.replace ("'", "''");
+    QString strQ = "SELECT " GV_C_ID " FROM " GV_CONTACTS_TABLE
+                 +  QString(" WHERE " GV_C_NAME " LIKE '%%%1%%' ")
+                            .arg (scrubContact)
+                 + "ORDER BY " GV_C_NAME;
+    query.exec (strQ);
+    while (query.next ()) {
+        info.init ();
+        info.strId = query.value(0).toString ();
+        if (getContactFromLink (info)) {
+            foreach (PhoneInfo phone, info.arrPhones) {
+                GVApi::simplify_number (phone.strNumber, false);
+                arrNums += phone.strNumber.replace("'", "''");
+            }
+        }
+    }
+
+    // We have all the ID's to look for
+    if (arrNums.isEmpty ()) {
+        Q_WARN(QString("Not a single ID matched the search string %1")
+               .arg (strContact));
+        return rv;
+    }
+
+    strQ = QString("SELECT "
+            GV_IN_ATTIME ","
+            GV_IN_DISPNUM ","
+            GV_IN_PHONE ","
+            GV_IN_SMSTEXT " "
+            "FROM " GV_INBOX_TABLE " "
+            "WHERE (" GV_IN_PHONE " LIKE '%%%1%%') "
+            "AND " GV_IN_TYPE " == %2 "
+            "ORDER BY " GV_IN_ATTIME " DESC")
+            .arg (arrNums.join ("%%' OR " GV_IN_PHONE " LIKE '%%"))
+            .arg (GVIE_TextMessage);
+
+    query.exec (strQ);
+    while (query.next ()) {
+        QString oneLine;
+        bool bok;
+        uint iDtTime = query.value (0).toInt (&bok);
+        if (!bok) {
+            break;
+        }
+
+        QString strNum = query.value(2).toString();
+        GVApi::simplify_number (strNum, false);
+        ContactInfo info;
+        getContactFromNumber (strNum, info);
+
+        // date,'dispnum','num','text'
+        oneLine = QDateTime::fromTime_t(iDtTime).toString (Qt::ISODate);
+        oneLine += ",'";
+        oneLine += info.strTitle.replace("'", "''");
+        oneLine += "','";
+        oneLine += query.value(2).toString().replace("'", "''");
+        oneLine += "','";
+        oneLine += query.value(3).toString().replace("'", "''");
+        oneLine += "'";
+
+        rv += oneLine;
+    }
+
+    return rv;
+}//CacheDb::getTextsByContact
+
+QStringList
+CacheDb::getTextsByDate(QDateTime dtStart, QDateTime dtEnd)
+{
+    CacheDbPrivate &p = CacheDbPrivate::ref();
+    QSqlQuery query(p.db);
+    query.setForwardOnly (true);
+
+    QString strQ = QString("SELECT "
+                                GV_IN_ATTIME ","
+                                GV_IN_PHONE ","
+                                GV_IN_SMSTEXT " "
+                           "FROM " GV_INBOX_TABLE " "
+                           "WHERE " GV_IN_ATTIME " >= %1 "
+                             "AND " GV_IN_ATTIME " <= %2 "
+                             "AND " GV_IN_TYPE " == %3 "
+                           "ORDER BY " GV_IN_ATTIME " DESC")
+            .arg (dtStart.toTime_t ())
+            .arg (dtEnd.toTime_t ())
+            .arg (GVIE_TextMessage);
+
+    QStringList rv;
+
+    query.exec (strQ);
+    while (query.next ()) {
+        QString oneLine;
+        bool bok;
+        uint iDtTime = query.value (0).toInt (&bok);
+        if (!bok) {
+            break;
+        }
+
+        QString strNum = query.value(1).toString();
+        GVApi::simplify_number (strNum, false);
+        ContactInfo info;
+        getContactFromNumber (strNum, info);
+
+        // date,'name','num','text'
+        oneLine = QDateTime::fromTime_t(iDtTime).toString (Qt::ISODate);
+        oneLine += ",'";
+        oneLine += info.strTitle.replace("'", "''");
+        oneLine += "','";
+        oneLine += query.value(1).toString().replace("'", "''");
+        oneLine += "','";
+        oneLine += query.value(2).toString().replace("'", "''");
+        oneLine += "'";
+
+        rv += oneLine;
+    }
+
+    return rv;
+}//CacheDb::getTextsByDate
+
+bool
+CacheDb::getCINumber(const QString &id, QString &num)
+{
+    CacheDbPrivate &p = CacheDbPrivate::ref();
+    QSqlQuery query(p.db);
+    query.setForwardOnly (true);
+
+    QString scrubId = id;
+    scrubId.replace ("'", "''");
+
+    QString strQ = QString("SELECT " GV_CI_NUMBER " FROM " GV_CI_TABLE " "
+                           "WHERE " GV_CI_ID " == '%1'")
+                    .arg (scrubId);
+
+    query.exec (strQ);
+    if (!query.next ()) {
+        return false;
+    }
+    num = query.value (0).toString ();
+    return true;
+}//CacheDb::getCINumber
+
+bool
+CacheDb::setCINumber(const QString &id, const QString &num)
+{
+    CacheDbPrivate &p = CacheDbPrivate::ref();
+    QSqlQuery query(p.db);
+    query.setForwardOnly (true);
+
+    QString scrubId = id;
+    QString scrubNum = num;
+    scrubId.replace ("'", "''");
+    scrubNum.replace ("'", "''");
+
+    QString strQ = QString("INSERT INTO " GV_CI_TABLE " ("
+                                GV_CI_ID "," GV_CI_NUMBER ") "
+                           "VALUES ('%1', '%2')")
+                    .arg (scrubId, scrubNum);
+
+    return query.exec (strQ);
+}//CacheDb::setCINumber
