@@ -20,7 +20,9 @@ Contact: yuvraaj@gmail.com
 */
 
 #include "MainWindow.h"
-#include "QtDeclarative"
+#include "QmlView.h"
+
+#include "QtSingleApplication"
 
 #include "ContactsModel.h"
 #include "InboxModel.h"
@@ -31,9 +33,30 @@ Contact: yuvraaj@gmail.com
 #error Must define the unknown contact QRC path
 #endif
 
+QApplication *
+createAppObject(int &argc, char **argv)
+{
+    QtSingleApplication *app;
+
+    app = new QtSingleApplication(argc, argv);
+    if (NULL == app) {
+        return app;
+    }
+
+    if (app->isRunning ()) {
+        app->sendMessage ("show");
+        delete app;
+        app = NULL;
+    } else {
+        app->setQuitOnLastWindowClosed (false);
+    }
+
+    return app;
+}//createAppObject
+
 MainWindow::MainWindow(QObject *parent)
 : IMainWindow(parent)
-, m_view()
+, m_view(new QmlView)
 , mainPageStack(NULL)
 , mainTabGroup(NULL)
 , loginExpand(NULL)
@@ -45,26 +68,45 @@ MainWindow::MainWindow(QObject *parent)
 , appPwDlg(NULL)
 , contactsList(NULL)
 , inboxList(NULL)
+, inboxSelector(NULL)
 , proxySettingsPage(NULL)
 , selectedNumberButton(NULL)
 , regNumberSelector(NULL)
 , ciSelector(NULL)
+, statusBanner(NULL)
 {
 }//MainWindow::MainWindow
 
+MainWindow::~MainWindow()
+{
+    if (NULL != m_view) {
+        delete m_view;
+        m_view = NULL;
+    }
+}//MainWindow::~MainWindow
+
 void
 MainWindow::init()
 {
     IMainWindow::init ();
 
     bool rv =
-    connect(&m_view, SIGNAL(statusChanged(QDeclarativeView::Status)),
+    connect(m_view, SIGNAL(statusChanged(QDeclarativeView::Status)),
             this, SLOT(declStatusChanged(QDeclarativeView::Status)));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    m_view.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
-    m_view.setMainQmlFile(QLatin1String("qml/harmattan/main.qml"));
-    m_view.showExpanded();
+    m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
+    m_view->setMainQmlFile(QLatin1String("qml/harmattan/main.qml"));
+    m_view->showExpanded();
+
+    rv = connect(qApp, SIGNAL(messageReceived(QString)),
+                 this, SLOT(messageReceived(QString)));
+    if (!rv) {
+        Q_WARN("Failed to connect to message received signal");
+        qApp->quit ();
+        exit(-1);
+        return;
+    }
 }//MainWindow::init
 
 QObject *
@@ -72,7 +114,7 @@ MainWindow::getQMLObject(const char *pageName)
 {
     QObject *pObj = NULL;
     do { // Begin cleanup block (not a loop)
-        QObject *pRoot = (QObject *) m_view.rootObject ();
+        QObject *pRoot = (QObject *) m_view->rootObject ();
         if (NULL == pRoot) {
             Q_WARN(QString("Couldn't get root object in QML for %1")
                     .arg(pageName));
@@ -113,6 +155,8 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == mainPageStack) {
             break;
         }
+        connect(mainPageStack, SIGNAL(sigShowContact(QString)),
+                &oContacts, SLOT(getContactInfoAndModel(QString)));
 
         mainTabGroup = getQMLObject ("MainTabGroup");
         if (NULL == mainTabGroup) {
@@ -166,6 +210,13 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         connect(inboxList, SIGNAL(clicked(QString)),
                 this, SLOT(onInboxClicked(QString)));
 
+        inboxSelector = getQMLObject ("InboxSelector");
+        if (NULL == inboxSelector) {
+            break;
+        }
+        connect(inboxSelector, SIGNAL(selectionChanged(QString)),
+                this, SLOT(onInboxSelectionChanged(QString)));
+
         appPwDlg = getQMLObject ("AppPwDialog");
         if (NULL == appPwDlg) {
             break;
@@ -204,12 +255,29 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         connect(ciSelector, SIGNAL(setCiNumber(QString,QString)),
                 &oPhones, SLOT(linkCiToNumber(QString,QString)));
 
+        statusBanner = getQMLObject ("StatusBanner");
+        if (NULL == statusBanner) {
+            break;
+        }
+
         onInitDone();
         return;
     } while(0);
     exit(-1);
 }//MainWindow::declStatusChanged
 
+void
+MainWindow::messageReceived(const QString &msg)
+{
+    if (msg == "show") {
+        Q_DEBUG ("Second instance asked us to show");
+        m_view->show ();
+    } else if (msg == "quit") {
+        Q_DEBUG ("Second instance asked us to quit");
+        qApp->quit ();
+    }
+}//MainWindow::messageReceived
+
 void
 MainWindow::uiUpdateProxySettings(const ProxyInfo &info)
 {
@@ -349,26 +417,33 @@ MainWindow::uiRefreshContacts()
 {
     Q_ASSERT(NULL != oContacts.m_contactsModel);
 
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_ContactsModel",
-                                        oContacts.m_contactsModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_ContactsModel",
+                                         oContacts.m_contactsModel);
     QMetaObject::invokeMethod (contactsList, "setMyModel");
 }//MainWindow::uiRefreshContacts
 
 void
 MainWindow::uiRefreshInbox()
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_InboxModel",
-                                        oInbox.m_inboxModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_InboxModel",
+                                         oInbox.m_inboxModel);
     QMetaObject::invokeMethod (inboxList, "setMyModel");
 }//MainWindow::uiRefreshInbox
 
+void
+MainWindow::uiSetSelelctedInbox(const QString &selection)
+{
+    QMetaObject::invokeMethod (inboxSelector, "setSelection",
+                               Q_ARG(QVariant, QVariant(selection)));
+}//MainWindow::uiSetSelelctedInbox
+
 void
 MainWindow::uiSetNewRegNumbersModel()
 {
-    m_view.engine()->rootContext()->setContextProperty("g_RegNumberModel",
-                                                       oPhones.m_numModel);
+    m_view->engine()->rootContext()->setContextProperty("g_RegNumberModel",
+                                                        oPhones.m_numModel);
     QMetaObject::invokeMethod (regNumberSelector, "setMyModel");
 }//MainWindow::uiSetNewRegNumbersModel
 
@@ -394,9 +469,9 @@ MainWindow::uiRefreshNumbers()
 void
 MainWindow::uiSetNewContactDetailsModel()
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_ContactPhonesModel",
-                                        oContacts.m_contactPhonesModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_ContactPhonesModel",
+                                         oContacts.m_contactPhonesModel);
 }//MainWindow::uiSetNewContactDetailsModel
 
 void
@@ -410,20 +485,66 @@ MainWindow::uiShowContactDetails(const ContactInfo &cinfo)
 void
 MainWindow::onInboxClicked(QString id)
 {
-//TODO: Something like
-    /*
-    QMetaObject::invokeMethod (mainPageStack, "showContactDetails",
-                               Q_ARG (QVariant, QVariant(cinfo.strPhotoPath)),
-                               Q_ARG (QVariant, QVariant(cinfo.strTitle)));
-    */
+    GVInboxEntry event;
+    QString type;
+    ContactInfo cinfo;
+
+    event.id = id;
+    if (!oInbox.getEventInfo (event, cinfo, type)) {
+        //TODO: Show error message
+        return;
+    }
+
+    if (!event.bRead) {
+        db.markAsRead (event.id);
+    }
+
+    QMetaObject::invokeMethod(mainPageStack, "showInboxDetails",
+                              Q_ARG(QVariant,QVariant(cinfo.strPhotoPath)),
+                              Q_ARG(QVariant,QVariant(event.strDisplayNumber)),
+                              Q_ARG(QVariant,QVariant(event.strPhoneNumber)),
+                              Q_ARG(QVariant,QVariant(type)),
+                              Q_ARG(QVariant,QVariant(cinfo.strId)));
 }//MainWindow::onInboxClicked
 
+void
+MainWindow::onInboxSelectionChanged(QString sel)
+{
+    oInbox.onUserSelect (sel);
+}//MainWindow::onInboxSelectionChanged
+
 void
 MainWindow::uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model)
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_CiPhonesModel", model);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_CiPhonesModel", model);
 
     QMetaObject::invokeMethod (mainPageStack, "pushCiSelector",
                                Q_ARG (QVariant, QVariant(num.id)));
 }//MainWindow::uiGetCIDetails
+
+void
+MainWindow::uiLongTaskBegins()
+{
+    QMetaObject::invokeMethod(statusBanner, "showMessage",
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedStatus)),
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedMillisconds)));
+}//MainWindow::uiLongTaskBegins
+
+void
+MainWindow::uiLongTaskContinues()
+{
+    QMetaObject::invokeMethod(statusBanner, "showMessage",
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedStatus)),
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedMillisconds)));
+}//MainWindow::uiLongTaskContinues
+
+void
+MainWindow::uiLongTaskEnds()
+{
+    QMetaObject::invokeMethod (statusBanner, "clearMessage");
+}//MainWindow::uiLongTaskEnds
