@@ -26,18 +26,22 @@ Contact: yuvraaj@gmail.com
 #include <QApplication>
 
 #include "IMainWindow.h"
-#include "qmlapplicationviewer.h"
 
+class QmlView;
 class MainWindow : public IMainWindow
 {
     Q_OBJECT
 public:
     explicit MainWindow(QObject *parent = 0);
+    virtual ~MainWindow();
+
     void init();
     void log(QDateTime dt, int level, const QString &strLog);
 
 protected slots:
     void declStatusChanged(QDeclarativeView::Status status);
+    void messageReceived(const QString &msg);
+
     void onLoginButtonClicked();
     void onTfaPinDlg(bool accepted);
     void onAppPwDlg(bool accepted);
@@ -47,6 +51,7 @@ protected slots:
                            QString pass);
 
     void onInboxClicked(QString id);
+    void onInboxSelectionChanged(QString sel);
 
 protected:
     QObject *getQMLObject(const char *pageName);
@@ -63,6 +68,8 @@ protected:
     void uiRefreshContacts();
     void uiRefreshInbox();
 
+    void uiSetSelelctedInbox(const QString &selection);
+
     void uiSetNewRegNumbersModel();
     void uiRefreshNumbers();
 
@@ -71,8 +78,12 @@ protected:
 
     void uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model);
 
+    void uiLongTaskBegins();
+    void uiLongTaskContinues();
+    void uiLongTaskEnds();
+
 private:
-    QmlApplicationViewer m_view;
+    QmlView *m_view;
 
     QObject *mainPageStack;
     QObject *mainTabGroup;
@@ -85,13 +96,18 @@ private:
     QObject *appPwDlg;
     QObject *contactsList;
     QObject *inboxList;
+    QObject *inboxSelector;
     QObject *proxySettingsPage;
     QObject *selectedNumberButton;
     QObject *regNumberSelector;
     QObject *ciSelector;
+    QObject *statusBanner;
 
     void    *loginCtx;
 
 };
 
+QApplication *
+createAppObject(int &argc, char **argv);
+
 #endif // MAINWINDOW_H
