@@ -19,10 +19,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 Contact: yuvraaj@gmail.com
 */
 
-#include <QtGui>
-#include "QtDeclarative"
-
 #include "MainWindow.h"
+#include "qmlapplicationviewer.h"
+
+#include "QtSingleApplication"
+
 #include "ContactsModel.h"
 #include "InboxModel.h"
 #include "GVNumModel.h"
@@ -36,21 +37,43 @@ Contact: yuvraaj@gmail.com
 #error Must define the unknown contact QRC path
 #endif
 
+QApplication *
+createAppObject(int &argc, char **argv)
+{
+    QtSingleApplication *app;
+
+    app = new QtSingleApplication(argc, argv);
+    if (NULL == app) {
+        return app;
+    }
+
+    if (app->isRunning ()) {
+        app->sendMessage ("show");
+        delete app;
+        app = NULL;
+    }
+
+    return app;
+}//createAppObject
+
 MainWindow::MainWindow(QObject *parent)
 : IMainWindow(parent)
-, m_view(NULL)
+, m_view(new QmlApplicationViewer)
 , tabbedUI(NULL)
+, closeButton(NULL)
 , loginExpand(NULL)
 , loginButton(NULL)
 , textUsername(NULL)
 , textPassword(NULL)
 , contactsList(NULL)
 , inboxList(NULL)
+, inboxSelector(NULL)
 , proxySettingsPage(NULL)
 , selectedNumberButton(NULL)
 , regNumberSelector(NULL)
 , ciSelector(NULL)
 , dialPage(NULL)
+, statusBanner(NULL)
 {
 }//MainWindow::MainWindow
 
@@ -60,21 +83,27 @@ MainWindow::init()
     IMainWindow::init ();
 
     bool rv =
-    connect(&m_view, SIGNAL(statusChanged(QDeclarativeView::Status)),
+    connect(m_view, SIGNAL(statusChanged(QDeclarativeView::Status)),
             this, SLOT(declStatusChanged(QDeclarativeView::Status)));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    m_view.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
-    m_view.setMainQmlFile(QLatin1String("qml/maemo/main.qml"));
-    m_view.showExpanded();
+    m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
+    m_view->setMainQmlFile(QLatin1String("qml/maemo/main.qml"));
+    m_view->showExpanded();
+    m_view->showFullScreen ();
 }//MainWindow::init
 
+MainWindow::~MainWindow()
+{
+    Q_DEBUG("Over and out");
+}//MainWindow::~MainWindow
+
 QObject *
 MainWindow::getQMLObject(const char *pageName)
 {
     QObject *pObj = NULL;
     do { // Begin cleanup block (not a loop)
-        QObject *pRoot = (QObject *) m_view.rootObject ();
+        QObject *pRoot = (QObject *) m_view->rootObject ();
         if (NULL == pRoot) {
             Q_WARN(QString("Couldn't get root object in QML for %1")
                     .arg(pageName));
@@ -114,6 +143,15 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == tabbedUI) {
             break;
         }
+        connect(tabbedUI, SIGNAL(sigOpenContact(QString)),
+                &oContacts, SLOT(getContactInfoAndModel(QString)));
+
+        closeButton = getQMLObject ("CloseButton");
+        if (NULL == closeButton) {
+            break;
+        }
+        connect(closeButton, SIGNAL(sigHide()), m_view, SLOT(hide()));
+        connect(closeButton, SIGNAL(sigClose()), qApp, SLOT(quit()));
 
         loginExpand = getQMLObject ("ExpandLoginDetails");
         if (NULL == loginExpand) {
@@ -148,6 +186,17 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         if (NULL == inboxList) {
             break;
         }
+        connect(inboxList, SIGNAL(clicked(QString)),
+                this, SLOT(onInboxClicked(QString)));
+        connect(inboxList, SIGNAL(showInboxSelector()),
+                this, SLOT(onInboxSelBtnClicked()));
+
+        inboxSelector = getQMLObject ("InboxSelector");
+        if (NULL == inboxList) {
+            break;
+        }
+        connect(inboxSelector, SIGNAL(done(bool)),
+                this, SLOT(onInboxSelected(bool)));
 
         proxySettingsPage = getQMLObject ("ProxySettingsPage");
         if (NULL == proxySettingsPage) {
@@ -192,6 +241,11 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
         //connect(dialPage, SIGNAL(sigText(QString)),
         //        this, SLOT(onUserText(QString)));
 
+        statusBanner = getQMLObject ("StatusBanner");
+        if (NULL == statusBanner) {
+            break;
+        }
+
         onInitDone();
         return;
     } while(0);
@@ -264,7 +318,7 @@ void
 MainWindow::uiRequestTFALoginDetails(void *ctx)
 {
     //TODO: Make sure this looks good
-    QString strPin = QInputDialog::getText(&m_view, tr("Enter PIN"),
+    QString strPin = QInputDialog::getText(m_view, tr("Enter PIN"),
                                            tr("Two factor authentication"));
 
     int pin = strPin.toInt ();
@@ -293,7 +347,7 @@ MainWindow::uiRequestApplicationPassword()
 {
     bool ok;
     QString strAppPw =
-    QInputDialog::getText (&m_view, "Application specific password",
+    QInputDialog::getText (m_view, "Application specific password",
                            "Enter password for contacts", QLineEdit::Password,
                            "", &ok);
     if (ok) {
@@ -318,7 +372,7 @@ MainWindow::uiLoginDone(int status, const QString &errStr)
     }
 
 #ifdef Q_WS_MAEMO_5
-    QMaemo5InformationBox::information(&m_view, msg);
+    QMaemo5InformationBox::information(m_view, msg);
 #endif
 }//MainWindow::uiLoginDone
 
@@ -327,26 +381,33 @@ MainWindow::uiRefreshContacts()
 {
     Q_ASSERT(NULL != oContacts.m_contactsModel);
 
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_ContactsModel",
-                                        oContacts.m_contactsModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_ContactsModel",
+                                         oContacts.m_contactsModel);
     QMetaObject::invokeMethod (contactsList, "setMyModel");
 }//MainWindow::uiRefreshContacts
 
 void
 MainWindow::uiRefreshInbox()
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_InboxModel",
-                                        oInbox.m_inboxModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_InboxModel",
+                                         oInbox.m_inboxModel);
     QMetaObject::invokeMethod (inboxList, "setMyModel");
 }//MainWindow::uiRefreshInbox()
 
+void
+MainWindow::uiSetSelelctedInbox(const QString &selection)
+{
+    QMetaObject::invokeMethod (inboxList, "setSelected",
+                               Q_ARG (QVariant, QVariant(selection)));
+}//MainWindow::uiSetSelelctedInbox
+
 void
 MainWindow::uiSetNewRegNumbersModel()
 {
-    m_view.engine()->rootContext()->setContextProperty("g_RegNumberModel",
-                                                       oPhones.m_numModel);
+    m_view->engine()->rootContext()->setContextProperty("g_RegNumberModel",
+                                                        oPhones.m_numModel);
     QMetaObject::invokeMethod (regNumberSelector, "setMyModel");
 }//MainWindow::uiSetNewRegNumbersModel
 
@@ -378,9 +439,9 @@ MainWindow::onUserClickedRegNumBtn()
 void
 MainWindow::uiSetNewContactDetailsModel()
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_ContactPhonesModel",
-                                        oContacts.m_contactPhonesModel);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_ContactPhonesModel",
+                                         oContacts.m_contactPhonesModel);
 }//MainWindow::uiSetNewContactDetailsModel
 
 void
@@ -391,12 +452,84 @@ MainWindow::uiShowContactDetails(const ContactInfo &cinfo)
                                Q_ARG (QVariant, QVariant(cinfo.strTitle)));
 }//MainWindow::uiShowContactDetails
 
+void
+MainWindow::onInboxClicked(QString id)
+{
+    GVInboxEntry event;
+    QString type;
+    ContactInfo cinfo;
+
+    event.id = id;
+    if (!oInbox.getEventInfo (event, cinfo, type)) {
+        //TODO: Show error message
+        return;
+    }
+
+    if (!event.bRead) {
+        db.markAsRead (event.id);
+    }
+
+    QMetaObject::invokeMethod(tabbedUI, "showInboxDetails",
+                              Q_ARG(QVariant,QVariant(cinfo.strPhotoPath)),
+                              Q_ARG(QVariant,QVariant(event.strDisplayNumber)),
+                              Q_ARG(QVariant,QVariant(event.strPhoneNumber)),
+                              Q_ARG(QVariant,QVariant(type)),
+                              Q_ARG(QVariant,QVariant(cinfo.strId)));
+}//MainWindow::onInboxClicked
+
+void
+MainWindow::onInboxSelBtnClicked()
+{
+    QMetaObject::invokeMethod (tabbedUI, "showInboxSelector");
+}//MainWindow::onInboxSelBtnClicked
+
+void
+MainWindow::onInboxSelected(bool accepted)
+{
+    if (!accepted) {
+        Q_DEBUG("Inbox selection not accepted");
+        return;
+    }
+
+    QString selected = inboxSelector->property("selected").toString();
+    if (!oInbox.onUserSelect (selected)) {
+        Q_WARN("Inbox selection not accepted");
+        return;
+    }
+}//MainWindow::onInboxSelected
+
 void
 MainWindow::uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model)
 {
-    m_view.engine()->rootContext()
-                   ->setContextProperty("g_CiPhonesModel", model);
+    m_view->engine()->rootContext()
+                    ->setContextProperty("g_CiPhonesModel", model);
 
     QMetaObject::invokeMethod (tabbedUI, "showCiSelector",
                                Q_ARG (QVariant, QVariant(num.id)));
 }//MainWindow::uiGetCIDetails
+
+void
+MainWindow::uiLongTaskBegins()
+{
+    QMetaObject::invokeMethod(statusBanner, "showMessage",
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedStatus)),
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedMillisconds)));
+}//MainWindow::uiLongTaskBegins
+
+void
+MainWindow::uiLongTaskContinues()
+{
+    QMetaObject::invokeMethod(statusBanner, "showMessage",
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedStatus)),
+                              Q_ARG(QVariant,
+                                    QVariant(m_taskInfo.suggestedMillisconds)));
+}//MainWindow::uiLongTaskContinues
+
+void
+MainWindow::uiLongTaskEnds()
+{
+    QMetaObject::invokeMethod (statusBanner, "clearMessage");
+}//MainWindow::uiLongTaskEnds
