@@ -26,13 +26,15 @@ Contact: yuvraaj@gmail.com
 #include <QApplication>
 
 #include "IMainWindow.h"
-#include "qmlapplicationviewer.h"
 
+class QmlApplicationViewer;
 class MainWindow : public IMainWindow
 {
     Q_OBJECT
 public:
     explicit MainWindow(QObject *parent = 0);
+    ~MainWindow();
+
     void init();
     void log(QDateTime dt, int level, const QString &strLog);
 
@@ -45,6 +47,10 @@ protected slots:
                            QString pass);
     void onUserClickedRegNumBtn();
 
+    void onInboxClicked(QString id);
+    void onInboxSelBtnClicked();
+    void onInboxSelected(bool accepted);
+
 protected:
     QObject *getQMLObject(const char *pageName);
 
@@ -60,6 +66,8 @@ protected:
     void uiRefreshContacts();
     void uiRefreshInbox();
 
+    void uiSetSelelctedInbox(const QString &selection);
+
     void uiSetNewRegNumbersModel();
     void uiRefreshNumbers();
 
@@ -68,21 +76,31 @@ protected:
 
     void uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model);
 
+    void uiLongTaskBegins();
+    void uiLongTaskContinues();
+    void uiLongTaskEnds();
+
 private:
-    QmlApplicationViewer m_view;
+    QmlApplicationViewer *m_view;
 
     QObject *tabbedUI;
+    QObject *closeButton;
     QObject *loginExpand;
     QObject *loginButton;
     QObject *textUsername;
     QObject *textPassword;
     QObject *contactsList;
     QObject *inboxList;
+    QObject *inboxSelector;
     QObject *proxySettingsPage;
     QObject *selectedNumberButton;
     QObject *regNumberSelector;
     QObject *ciSelector;
     QObject *dialPage;
+    QObject *statusBanner;
 };
 
+QApplication *
+createAppObject(int &argc, char **argv);
+
 #endif // MAINWINDOW_H
