@@ -39,8 +39,16 @@ public:
     void fill(const GVInboxEntry &event);
     void fill(const ContactInfo &cinfo);
 
+private slots:
+    void onNumberDoubleClicked();
+    void onContactDoubleClicked();
+
 private:
     Ui::InboxEntryDialog *ui;
+
+public:
+    bool m_numberDoubleClicked;
+    bool m_contactDoubleClicked;
 };
 
 #endif // INBOXENTRYDIALOG_H
