@@ -19,7 +19,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 Contact: yuvraaj@gmail.com
 */
 
+#ifndef Q_OS_BLACKBERRY
 #include "QtSingleApplication"
+#endif
+
 #include "MainWindow.h"
 #include "MainWindow_p.h"
 #include "ui_mainwindow.h"
@@ -45,8 +48,9 @@ Contact: yuvraaj@gmail.com
 #error Must define the unknown contact QRC path
 #endif
 
+#ifndef Q_OS_BLACKBERRY
 QCoreApplication *
-createApplication(int argc, char *argv[])
+createAppObject(int argc, char *argv[])
 {
     QtSingleApplication *app;
 //#ifdef Q_WS_WIN32
@@ -63,14 +67,32 @@ createApplication(int argc, char *argv[])
         app->sendMessage ("show");
         delete app;
         app = NULL;
+    } else {
+        app->setQuitOnLastWindowClosed (false);
     }
 
     return app;
-}//createApplication
+}//createAppObject
+#else
+QCoreApplication *
+createAppObject(int argc, char *argv[])
+{
+    QApplication *app = new QApplication(argc, argv);
+    if (NULL == app) {
+        return app;
+    }
+
+    app->setQuitOnLastWindowClosed (false);
+    return app;
+}//createAppObject
+#endif
 
 MainWindow::MainWindow(QObject *parent)
 : IMainWindow(parent)
 , d(new MainWindowPrivate)
+, m_appIcon(":/qgv.png")
+, m_systrayIcon(NULL)
+, m_ignoreCbInboxChange(false)
 {
 }//MainWindow::MainWindow
 
@@ -86,6 +108,7 @@ MainWindow::init()
 {
     IMainWindow::init ();
 
+#ifndef Q_OS_BLACKBERRY
     bool rv = connect(qApp, SIGNAL(messageReceived(QString)),
                       this, SLOT(messageReceived(QString)));
     if (!rv) {
@@ -96,6 +119,7 @@ MainWindow::init()
     }
 
     ((QtSingleApplication *)qApp)->setActivationWindow (this->d);
+#endif
 
 #if DESKTOP_OS
     // Desktop only ?
@@ -154,11 +178,43 @@ MainWindow::init()
     connect(d->ui->contactsView, SIGNAL(doubleClicked(const QModelIndex&)),
             this, SLOT(onContactDoubleClicked(const QModelIndex&)));
 
-    connect(d->ui->inboxView, SIGNAL(clicked(const QModelIndex&)),
-            this, SLOT(onInboxClicked(const QModelIndex&)));
     connect(d->ui->inboxView, SIGNAL(doubleClicked(const QModelIndex&)),
             this, SLOT(onInboxDoubleClicked(const QModelIndex&)));
 
+    d->ui->cbInboxSelector->addItem("All");
+    d->ui->cbInboxSelector->addItem("Placed");
+    d->ui->cbInboxSelector->addItem("Missed");
+    d->ui->cbInboxSelector->addItem("Received");
+    d->ui->cbInboxSelector->addItem("Voicemail");
+    d->ui->cbInboxSelector->addItem("SMS");
+    connect(d->ui->cbInboxSelector, SIGNAL(currentIndexChanged(const QString&)),
+            this, SLOT(onCbInboxChanged(const QString&)));
+
+    if (QSystemTrayIcon::isSystemTrayAvailable ()) {
+        m_systrayIcon = new QSystemTrayIcon(d);
+        if (NULL == m_systrayIcon) {
+            Q_CRIT("Failed to create system tray icon");
+            qApp->quit ();
+            return;
+        }
+
+        connect(m_systrayIcon,
+                SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
+                this,
+                SLOT(onSystrayactivated(QSystemTrayIcon::ActivationReason)));
+
+        m_systrayIcon->setIcon (m_appIcon);
+        m_systrayIcon->setContextMenu (d->ui->menu_File);
+        m_systrayIcon->show ();
+    }
+
+    d->setWindowIcon (m_appIcon);
+    d->setAllowClose (false);
+    connect(d->ui->action_Quit, SIGNAL(triggered()), qApp, SLOT(quit()));
+
+    connect(d->ui->actionRefresh, SIGNAL(triggered()),
+            this, SLOT(onUserRefreshTrigerred()));
+
     QTimer::singleShot (1, this, SLOT(onInitDone()));
 }//MainWindow::init
 
@@ -186,7 +242,8 @@ MainWindow::uiUpdateProxySettings(const ProxyInfo &info)
 void
 MainWindow::uiRequestLoginDetails()
 {
-    d->ui->statusBar->showMessage ("Please enter a user and password");
+    d->ui->statusBar->showMessage ("Please enter a user and password",
+                                   SHOW_INF);
     d->ui->tabWidget->setCurrentIndex (3);
     d->ui->toolBox->setCurrentIndex (0);
 }//MainWindow::uiRequestLoginDetails
@@ -265,10 +322,11 @@ MainWindow::uiLoginDone(int status, const QString &errStr)
 {
     do {
         if (ATTS_NW_ERROR == status) {
-            d->ui->statusBar->showMessage ("Network error. Try again later.");
+            d->ui->statusBar->showMessage ("Network error. Try again later.",
+                                           SHOW_10SEC);
             break;
         } else if (ATTS_USER_CANCEL == status) {
-            d->ui->statusBar->showMessage ("User canceled login.");
+            d->ui->statusBar->showMessage ("User canceled login.", SHOW_5SEC);
             break;
         } else if (ATTS_SUCCESS != status) {
             QMessageBox msg;
@@ -279,7 +337,7 @@ MainWindow::uiLoginDone(int status, const QString &errStr)
             break;
         }
 
-        d->ui->statusBar->showMessage ("Login successful");
+        d->ui->statusBar->showMessage ("Login successful", SHOW_5SEC);
     } while (0);
 }//MainWindow::uiLoginDone
 
@@ -288,11 +346,6 @@ MainWindow::uiRefreshContacts()
 {
     Q_ASSERT(NULL != oContacts.m_contactsModel);
 
-    connect(oContacts.m_contactsModel, SIGNAL(noContactPhoto(QString,QString)),
-            &oContacts, SLOT(onNoContactPhoto(QString,QString)));
-    connect(&oContacts, SIGNAL(someTimeAfterGettingTheLastPhoto()),
-            this, SLOT(someTimeAfterGettingTheLastPhoto()));
-
     d->ui->contactsView->setModel (oContacts.m_contactsModel);
 
     d->ui->contactsView->hideColumn (0);    // id
@@ -307,9 +360,43 @@ MainWindow::uiRefreshInbox()
 
     d->ui->inboxView->hideColumn (0);
     d->ui->inboxView->hideColumn (1);
+    d->ui->inboxView->resizeColumnToContents(2);
+    d->ui->inboxView->resizeColumnToContents(3);
+    d->ui->inboxView->resizeColumnToContents(4);
     d->ui->inboxView->hideColumn (5);
+
+    int width = d->ui->inboxView->width() - d->ui->inboxView->columnWidth (4);
+    width >>= 1;
+    width--;
+    if (d->ui->inboxView->columnWidth(2) < (width - 2)) {
+        d->ui->inboxView->setColumnWidth (2, width - 2);
+    }
+    if (d->ui->inboxView->columnWidth(3) < (width - 2)) {
+        d->ui->inboxView->setColumnWidth (3, width - 2);
+    }
 }//MainWindow::uiRefreshInbox
 
+void
+MainWindow::uiSetSelelctedInbox(const QString &selection)
+{
+    int pos = d->ui->cbInboxSelector->findText(selection, Qt::MatchFixedString);
+    if (-1 != pos) {
+        m_ignoreCbInboxChange = true;
+        d->ui->cbInboxSelector->setCurrentIndex(pos);
+        m_ignoreCbInboxChange = false;
+    } else {
+        Q_WARN(QString("Did not find \"%1\" in the ComboBox").arg(selection));
+    }
+}//MainWindow::uiSetSelelctedInbox
+
+void
+MainWindow::onCbInboxChanged(const QString &text)
+{
+    if (!m_ignoreCbInboxChange) {
+        oInbox.onUserSelect (text);
+    }
+}//MainWindow::onCbInboxChanged
+
 void
 MainWindow::uiSetNewRegNumbersModel()
 {
@@ -335,12 +422,6 @@ MainWindow::uiRefreshNumbers()
     }
 }//MainWindow::uiRefreshNumbers
 
-void
-MainWindow::someTimeAfterGettingTheLastPhoto()
-{
-    oContacts.refreshModel ();
-}//MainWindow::someTimeAfterGettingTheLastPhoto
-
 void
 MainWindow::messageReceived(const QString &msg)
 {
@@ -445,31 +526,48 @@ MainWindow::setNumberToDial(QString num)
 }//MainWindow::setNumberToDial
 
 void
-MainWindow::onInboxClicked(const QModelIndex &index)
+MainWindow::onInboxDoubleClicked(const QModelIndex &index)
 {
     QModelIndex idIndex = index.sibling (index.row (), 0);
     GVInboxEntry event;
+    ContactInfo cinfo;
+    QString type;
+
     event.id = idIndex.data().toString();
-    if (db.getInboxEntryById (event)) {
-        InboxEntryDialog dlg;
-        dlg.fill (event);
-
-        ContactInfo cinfo;
-        if (db.getContactFromNumber (event.strPhoneNumber, cinfo)) {
-            dlg.fill (cinfo);
-        }
-
-        //TODO: Show inbox details
-        dlg.exec ();
+    if (!oInbox.getEventInfo (event, cinfo, type)) {
+        //TODO: Some error
+        return;
     }
-}//MainWindow::onInboxClicked
 
-void
-MainWindow::onInboxDoubleClicked(const QModelIndex &index)
-{
-    QModelIndex numIndex = index.sibling (index.row (), 3);
-    setNumberToDial (numIndex.data().toString());
-}//MainWindow::onInboxClicked
+    if (!event.bRead) {
+        db.markAsRead (event.id);
+    }
+
+    InboxEntryDialog dlg;
+    dlg.fill (event);
+    dlg.fill (cinfo);
+
+    // Show inbox details
+    if (QDialog::Accepted != dlg.exec ()) {
+        return;
+    }
+
+    if (dlg.m_contactDoubleClicked) {
+        if (!cinfo.strId.isEmpty ()) {
+            ContactDialog dlg1;
+            connect(&dlg1, SIGNAL(selected(QString)),
+                    this, SLOT(setNumberToDial(QString)));
+            dlg1.fillAndExec (cinfo);
+        } else {
+            dlg.m_numberDoubleClicked = true;
+        }
+    }
+
+    if (dlg.m_numberDoubleClicked) {
+        QModelIndex numIndex = index.sibling (index.row (), 3);
+        setNumberToDial (numIndex.data().toString());
+    }
+}//MainWindow::onInboxDoubleClicked
 
 void
 MainWindow::uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model)
@@ -493,3 +591,62 @@ MainWindow::onCbNumDoModify(int index)
 {
     oPhones.onUserUpdateCiNumber (index);
 }//MainWindow::onCbNumDoModify
+
+void
+MainWindow::uiLongTaskBegins()
+{
+    switch (m_taskInfo.type) {
+    case LT_Login:
+        d->ui->statusBar->showMessage (m_taskInfo.suggestedStatus,
+                                       m_taskInfo.suggestedMillisconds);
+        break;
+    case LT_Call:
+        d->ui->statusBar->showMessage ("Setting up a call ...", SHOW_INF);
+        break;
+    default:
+        break;
+    }
+}//MainWindow::uiLongTaskBegins
+
+void
+MainWindow::uiLongTaskContinues()
+{
+    d->ui->statusBar->showMessage (m_taskInfo.suggestedStatus,
+                                   m_taskInfo.suggestedMillisconds);
+}//MainWindow::uiLongTaskContinues
+
+void
+MainWindow::uiLongTaskEnds()
+{
+    d->ui->statusBar->clearMessage ();
+}//MainWindow::uiLongTaskEnds
+
+void
+MainWindow::onSystrayactivated(QSystemTrayIcon::ActivationReason reason)
+{
+    switch (reason) {
+    case QSystemTrayIcon::Trigger:
+        if (d->isVisible ()) {
+            d->hide ();
+        } else {
+            d->show ();
+        }
+        break;
+
+    default:
+        break;
+    }
+}//MainWindow::onSystrayactivated
+
+void
+MainWindow::onUserRefreshTrigerred()
+{
+    QDateTime latest;
+    if (db.getLatestContact (latest)) {
+        oContacts.refresh (latest);
+    }
+
+    if (db.getLatestInboxEntry (latest)) {
+        oInbox.refresh ("all", latest);
+    }
+}//MainWindow::onUserRefreshTrigerred
