@@ -26,6 +26,8 @@ Contact: yuvraaj@gmail.com
 #include "IMainWindow.h"
 
 class MainWindowPrivate;
+class QSystemTrayIcon;
+
 class MainWindow : public IMainWindow
 {
     Q_OBJECT
@@ -39,7 +41,6 @@ public:
 
 public slots:
     void onLoginClicked();
-    void someTimeAfterGettingTheLastPhoto();
 
     void onUserProxyEnableChanged(bool newValue);
     void onUserUseSystemProxyChanged(bool newValue);
@@ -61,6 +62,8 @@ protected:
     void uiRefreshContacts();
     void uiRefreshInbox();
 
+    void uiSetSelelctedInbox(const QString &selection);
+
     void uiSetNewRegNumbersModel();
     void uiRefreshNumbers();
 
@@ -69,6 +72,10 @@ protected:
 
     void uiGetCIDetails(GVRegisteredNumber &num, GVNumModel *model);
 
+    void uiLongTaskBegins();
+    void uiLongTaskContinues();
+    void uiLongTaskEnds();
+
 protected slots:
     void messageReceived(const QString &msg);
 
@@ -76,16 +83,25 @@ protected slots:
     void onContactDoubleClicked(const QModelIndex &index);
     void setNumberToDial(QString num);
 
-    void onInboxClicked(const QModelIndex &index);
     void onInboxDoubleClicked(const QModelIndex &index);
 
     void onCbNumDoModify(int index);
+    void onCbInboxChanged(const QString &text);
+
+    void onSystrayactivated(QSystemTrayIcon::ActivationReason reason);
+
+    void onUserRefreshTrigerred();
 
 private:
     MainWindowPrivate *d;
+
+    QIcon            m_appIcon;
+    QSystemTrayIcon *m_systrayIcon;
+
+    bool m_ignoreCbInboxChange;
 };
 
 QCoreApplication *
-createApplication(int argc, char *argv[]);
+createAppObject(int argc, char *argv[]);
 
 #endif // MAINWINDOW_H
